@@ -1,5 +1,7 @@
 context("servers")
 
+skip_on_cran()
+
 test_that("servers", {
   vcr::use_cassette("servers", {
     aa <- servers()
@@ -7,6 +9,5 @@ test_that("servers", {
 
   expect_is(aa, "data.frame")
   expect_is(aa, "tbl")
-  expect_named(aa, c("name", "url", "public"))
   expect_is(aa$public, "logical")
 })
